@@ -1,6 +1,6 @@
-/* $Id: xfce-kiosk.c 17217 2005-08-31 10:19:12Z benny $ */
+/* $Id$ */
 /*-
- * Copyright (c) 2003-2005 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -50,6 +50,8 @@
 #endif
 
 #include <libxfce4util/libxfce4util.h>
+#include <libxfce4util/libxfce4util-alias.h>
+
 
 
 #define KIOSKRC (KIOSKDIR "/kioskrc")
@@ -249,18 +251,18 @@ xfce_kiosk_init (void)
   int            gidsetlen;
   int            n;
   int            m;
-  time_t         time;
+  time_t         timestamp;
 
   G_LOCK (kiosk_lock);
 
   /* reload kioskrc */
-  time = mtime (KIOSKRC);
-  if (time > kiosktime || kioskdef == NULL)
+  timestamp = mtime (KIOSKRC);
+  if (timestamp > kiosktime || kioskdef == NULL)
     {
       if (kioskrc != NULL)
         xfce_rc_close (kioskrc);
 
-      kiosktime = time;
+      kiosktime = timestamp;
       kioskrc = xfce_rc_simple_open (KIOSKRC, TRUE);
       if (kioskrc != NULL)
         {
@@ -342,3 +344,6 @@ mtime (const gchar *path)
 }
 
 
+
+#define __XFCE_KIOSK_C__
+#include <libxfce4util/libxfce4util-aliasdef.c>
